#ifndef __cplusplus
#	include <stdlib.h>
#else
#	include <cstdlib>
#endif
#include <libHX/option.h>

static unsigned int g_verbose;
static const struct HXoption t[] = {
	{nullptr, 'v', HXTYPE_NONE | HXOPT_INC, &g_verbose},
	HXOPT_AUTOHELP,
	HXOPT_TABLEEND,
};

int main(int argc, const char **argv)
{
	HX_getopt(t, &argc, &argv, HXOPT_USAGEONERR);
	return EXIT_SUCCESS;
}
